@@ -165,8 +165,11 @@ class LogData:
             ["{0}:{1}".format(k, v) for k, v in kwargs.items()
              if v is not None])
         ))
+        limit = None
+        if "limit" in kwargs:
+            limit = kwargs.pop("limit")
         assert len(kwargs) >= 1, "empty arguments"
-        for d_line in self.db.iter_lines(kwargs):
+        for d_line in self.db.iter_lines(kwargs, limit=limit):
             yield self._row_to_lm(d_line)
 
     def iter_all(self):
@@ -181,8 +184,8 @@ class LogData:
             ltid (Optional[int]): Search tags for given log template identifier.
             ltgid (Optional[int]): Search tags for given group identifier.
 
-        Returns:
-            List[str]
+        Yields:
+            str
         """
         assert len(kwargs) >= 1, "empty arguments"
         return self.db.get_tags(**kwargs)
@@ -281,7 +284,7 @@ class LogData:
 
     def show_lt_info(self, ltid):
         ltobj = self.lt(ltid)
-        tags = self.get_tags(ltid=ltobj.ltid)
+        tags = [tag for tag in self.get_tags(ltid=ltobj.ltid)]
         if tags:
             tag_str = "|".join(tags)
             return " ".join((str(ltobj.ltid), "({0})".format(tag_str),
@@ -291,15 +294,15 @@ class LogData:
                              str(ltobj), "({0})".format(ltobj.count)))
 
     def show_ltg_info(self, ltgid):
-        tags = self.get_tags(ltgid=ltgid)
+        tags = [tag for tag in self.get_tags(ltgid=ltgid)]
         l_ltobj = self.ltg_members(ltgid)
         length = len(l_ltobj)
         count = sum(ltobj.count for ltobj in l_ltobj)
 
         header = "[ltgroup {0} ({1} tpls, {2} lines)]".format(
-            ltgid, length, count, ", ".join(tags)
+            ltgid, length, count,
         )
-        if tags:
+        if len(tags) > 0:
             header += " # tags: {0}".format(",".join(tags))
         buf = [header]
         for ltobj in l_ltobj:
@@ -331,6 +334,7 @@ class LogDB:
     indexname_log = "log_index"
     indexname_ltg = "ltg_index"
     indexname_tag = "tag_index"
+    index_names = (indexname_log, indexname_ltg, indexname_tag)
     _tablename_tmp_footer = "_tmp"
 
     def __init__(self, conf, edit, reset_db):
@@ -449,6 +453,46 @@ class LogDB:
         sql = self._db.create_index_sql(table_name, index_name, l_key)
         self._db.execute(sql)
 
+    def repair_tables(self):
+        current_table_names = self._db.get_table_names()
+
+        for name in self.table_names:
+            if name not in current_table_names:
+                if name == self.tablename_log:
+                    raise ValueError("Empty database, cannot be repaired")
+                elif name == self.tablename_lt:
+                    raise ValueError("No log templates, cannot be repaired")
+                elif name == self.tablename_ltg:
+                    print("no ltg table, init table")
+                    self._init_table_ltg()
+                    print("NOTE: try \"\" db-remake-group if you need afterward")
+                elif name == self.tablename_tag:
+                    print("no tag table, init table")
+                    self._init_table_tag()
+                    print("NOTE: try \"\" db-tag if you need afterward")
+
+        for name in self.index_names:
+            if name not in current_table_names:
+                if name == self.indexname_log:
+                    print("no log index, init")
+                    self._init_index_log()
+                elif name == self.indexname_ltg:
+                    print("no ltg index, init")
+                    self._init_index_ltg()
+                elif name == self.indexname_tag:
+                    print("no tag index, init")
+                    self._init_index_tag()
+
+        for name in current_table_names:
+            if self._tablename_tmp_footer in name:
+                print("remove temporal table")
+                sql = self._db.drop_table_sql(name)
+                self._db.execute(sql)
+
+        self._db.commit()
+        current_table_names = self._db.get_table_names()
+        print("now the db has {0}".format(current_table_names))
+
     def switch_temporal_table(self, table_name):
         """Switch valid table to temporal one.
         Used for large data update."""
@@ -570,7 +614,7 @@ class LogDB:
                 d_line["l_w"] = strutil.split_igesc(row[4], self._splitter)
             yield d_line
 
-    def iter_lines(self, conditions):
+    def iter_lines(self, conditions, limit=None):
         d_cond = {k: v for k, v in conditions.items()
                   if v is not None}
         if len(d_cond) == 0:
@@ -582,7 +626,7 @@ class LogDB:
         if "end_dt" in d_cond and "dte" not in d_cond:
             d_cond["dte"] = d_cond.pop("end_dt")
 
-        for row in self._select_log(d_cond):
+        for row in self._select_log(d_cond, limit=limit):
             yield self._parse_row(row)
 
     def iter_words(self, conditions):
@@ -603,7 +647,7 @@ class LogDB:
             else:
                 yield strutil.split_igesc(row[4], self._splitter)
 
-    def _select_log(self, d_cond, l_order=None):
+    def _select_log(self, d_cond, l_order=None, limit=None):
         # if len(d_cond) == 0:
         #     raise ValueError("called select with empty condition")
         args = d_cond.copy()
@@ -624,7 +668,7 @@ class LogDB:
                 args[c] = self._db.strftime(d_cond[c])
             else:
                 l_cond.append(db_common.Condition(c, "=", c, True))
-        sql = self._db.select_sql(table_name, l_key, l_cond, l_order)
+        sql = self._db.select_sql(table_name, l_key, l_cond, l_order, limit)
         return self._db.execute(sql, args)
 
     def get_line(self, lid):
@@ -874,7 +918,7 @@ class LogDB:
         # compatibility
         l_table_name = self._db.get_table_names()
         if self.tablename_tag not in l_table_name:
-            return []
+            return
 
         if "ltgid" in kwargs:
             table_name = self._db.join_sql("left outer",
@@ -896,7 +940,10 @@ class LogDB:
             cursor = self._db.execute(sql, args)
         else:
             raise ValueError("No identifier given")
-        return [row[0] for row in cursor]
+
+        for row in cursor:
+            if row[0] is not None:
+                yield row[0]
 
     def iter_tag_def(self):
         table_name = self.tablename_tag
@@ -1038,7 +1085,7 @@ def show_all_ltg(conf):
     ld = LogData(conf)
     for gid in ld.iter_ltgid():
         buf.append(ld.show_ltg_info(gid))
-    return "\n".join(buf)
+    return "\n\n".join(buf)
 
 
 def show_tag(conf, tag=None):
