@@ -86,6 +86,9 @@ class LogTemplate:
         else:
             raise KeyError
 
+    def desc(self):
+        return [w for w in self.ltw if w != REPLACER]
+
     def var(self, l_w):
         if len(l_w) == 0:
             return [REPLACER for w in self.ltw if w == REPLACER]
@@ -479,7 +482,7 @@ class LTGroup(ABC):
     def make(self):
         raise NotImplementedError
 
-    def add_ltid(self, gid, ltline):
+    def add_lt(self, gid, ltline):
         self._d_group.setdefault(gid, []).append(ltline)
         self._d_rgroup[ltline.ltid] = gid
 
@@ -488,6 +491,11 @@ class LTGroup(ABC):
             self._d_group.setdefault(ltgid, []).append(table[ltid])
             self._d_rgroup[ltid] = ltgid
 
+    def update_lttable(self, lttable):
+        for ltid, ltgid in self._d_rgroup.items():
+            lttable[ltid].ltgid = ltgid
+        return lttable
+
     def load(self, loadobj):
         pass
 
@@ -522,7 +530,7 @@ class LTGroupDummy(LTGroupOnline):
 
     def add(self, ltline):
         gid = ltline.ltid
-        self.add_ltid(gid, ltline)
+        self.add_lt(gid, ltline)
         return gid
 
 
@@ -619,3 +627,23 @@ def merged_template(m1, m2):
         else:
             ret.append(REPLACER)
     return ret
+
+
+def template_from_messages(l_lm):
+    """Generate a log template as the common part of given instances.
+
+    Args:
+        l_lm (List[log_db.LogMessage]): Log instances
+
+    Returns:
+        tpl (List[str])
+    """
+    tpl = []
+    for words in zip(*[lm.l_w for lm in l_lm]):
+        s_words = set(words)
+        s_words.discard(REPLACER)
+        if len(s_words) == 1:
+            tpl.append(words[0])
+        else:
+            tpl.append(REPLACER)
+    return tpl
